==> objectify-alpha_30.5.tgz: objectify-alpha_30.5/testing/test_import_sizes.sh <==
#
#          This file is part of the New World OS and Objectify projects
#                        Copyright (C) 2009  QRW Software
#               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program, in the file LICENSE.  If not, see 
#   <http://www.gnu.org/licenses/>.
#
#   For the latest information, source code (SVN), releases, bug and feature
#   request tracking go to:
#      http://sourceforge.net/projects/objectify
#
#   For older bug tracking, releases and source code (CVS) prior to the
#   Alpha_30 release go to:
#      http://sourceforge.net/projects/nwos
#
#   Other related websites:
#      http://www.qrwsoftware.com
#      http://www.worldwide-database.org
#
#   You can also contact me via paper mail at:
#
#      QRW Software
#      P.O. Box 27511
#      Salt Lake City, UT 84127-0511, USA.
#
#   $Author: jsedwards $
#   $Date: 2009-09-20 13:04:12 -0600 (Sun, 20 Sep 2009) $
#   $Revision: 4372 $
#
#   NOTE: Subversion does not support the Log keyword so I have removed the
#   logs that were here when I was using CVS.  Use the "svn log" command to
#   see the revision history of this file.
#   (See http://subversion.tigris.org/faq.html#log-in-source)
# 


export OBJECTIFY_TEST_ONLY_DO_NOT_USE="Import Sizes Test"
export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private.obj
export OBJECTIFY_LOG_FILE_PATH=/tmp/objectify_test/objectify_log
export OBJECTIFY_BACKUP_PATH=

EXEC=$PWD

if ! rm -fr /tmp/objectify_test; then
   echo ""
   echo "could not remove /tmp/objectify_test directory"
   echo ""
   exit 1
fi

if ! rm -fr /tmp/test; then
   echo ""
   echo "could not remove /tmp/objectify_test directory"
   echo ""
   exit 1
fi

mkdir /tmp/test
cd /tmp/test

echo "----------------------"
echo " creating test files"
echo "----------------------"

#dd if=/dev/random of=x7 bs=7 count=1

echo "WARNING: NOT using random data!!!!!"
echo -n "1234567" > x7

cat          x7          x7 >        x14
cat         x14         x14 >        x28
cat         x28         x28 >        x56
cat         x56         x56 >       x112
cat        x112        x112 >       x224
cat        x224        x224 >       x448
cat        x448        x448 >       x896
cat        x896        x896 >      x1792
cat       x1792       x1792 >      x3584
cat       x3584       x3584 >      x7168
cat       x7168       x7168 >     x14336
cat      x14336      x14336 >     x28672
cat      x28672      x28672 >     x57344
cat      x57344      x57344 >    x114688
cat     x114688     x114688 >    x229376
cat     x229376     x229376 >    x458752
cat     x458752     x458752 >    x917504
cat     x917504     x917504 >   x1835008
cat    x1835008    x1835008 >   x3670016
cat    x3670016    x3670016 >   x7340032
cat    x7340032    x7340032 >  x14680064
cat   x14680064   x14680064 >  x29360128
cat   x29360128   x29360128 >  x58720256
cat   x58720256   x58720256 > x117440512


echo "---------------"
echo " prep disk..."
echo "---------------"
if ! $EXEC/src/apps/util/prep_archive; then
   echo ""
   echo "prep_archive failed"
   echo ""
   exit 1
fi

echo "---------------"
echo " import_files..."
echo "---------------"
if ! $EXEC/src/apps/file/import_file x*; then
   echo ""
   echo "import_file failed"
   echo ""
   exit 1
fi


echo "-----------------"
echo " export_files..."
echo "-----------------"

mkdir test
cd test

if ! $EXEC/src/apps/file/export_file "*"; then
   echo ""
   echo "export_file failed"
   echo ""
   exit 1
fi

for file in ../x*; do diff -s $file .; done
sleep 2

echo "---------------------"
echo " verify and remove..."
echo "---------------------"
if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
   echo ""
   echo "verify_file --remove-no-shred succeeded"
   echo ""
   exit 1
fi


echo "---------------------"
echo " compress..."
echo "---------------------"
if ! $EXEC/src/apps/util/compress_archive ../compressed; then
   echo ""
   echo "compress_archive failed"
   echo ""
   exit 1
fi


echo "--------------------------"
echo " prep disk for restore..."
echo "--------------------------"
if ! $EXEC/src/apps/util/prep_archive --no-private; then
   echo ""
   echo "prep_archive --no-private failed"
   echo ""
   exit 1
fi


echo "---------------------"
echo " expand..."
echo "---------------------"
if ! $EXEC/src/apps/util/restore_archive ../compressed; then
   echo ""
   echo "restore_archive failed"
   echo ""
   exit 1
fi



if ! $EXEC/src/apps/file/export_file "*"; then
   echo ""
   echo "export_file failed"
   echo ""
   exit 1
fi

for file in ../*.[ch]; do diff -s $file .; done


echo "---------------------"
echo " verify and remove..."
echo "---------------------"
if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
   echo ""
   echo "verify_file --remove-no-shred failed"
   echo ""
   exit 1
fi

echo ""
echo "All tests passed!"
echo ""

exit 0

==> objectify-alpha_30.6.tgz: objectify-alpha_30.6/testing/test_import_sizes.sh <==
#
#          This file is part of the New World OS and Objectify projects
#                     Copyright (C) 2009, 2010  QRW Software
#               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program, in the file LICENSE.  If not, see 
#   <http://www.gnu.org/licenses/>.
#
#   For the latest information, source code (SVN), releases, and bug tracking
#   go to:
#      http://savannah.nongnu.org/projects/objectify
#
#   For releases from Alpha_30 and up, bug and feature request tracking go to:
#      http://sourceforge.net/projects/objectify
#
#   For older bug tracking, releases and source code (CVS) prior to the
#   Alpha_30 release go to:
#      http://sourceforge.net/projects/nwos
#
#   Other related websites:
#      http://www.qrwsoftware.com
#      http://www.worldwide-database.org
#
#   You can also contact me via paper mail at:
#
#      QRW Software
#      P.O. Box 27511
#      Salt Lake City, UT 84127-0511, USA.
#
#   $Author: jsedwards $
#   $Date: 2010-01-30 08:57:28 -0700 (Sat, 30 Jan 2010) $
#   $Revision: 4510 $
#
#   NOTE: Subversion does not support the Log keyword so I have removed the
#   logs that were here when I was using CVS.  Use the "svn log" command to
#   see the revision history of this file.
#   (See http://subversion.tigris.org/faq.html#log-in-source)
# 


export OBJECTIFY_TEST_ONLY_DO_NOT_USE="Import Sizes Test"
export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private.obj
export OBJECTIFY_LOG_FILE_PATH=/tmp/objectify_test/objectify_log
export OBJECTIFY_BACKUP_PATH=

EXEC=$PWD

if ! rm -fr /tmp/objectify_test; then
   echo ""
   echo "could not remove /tmp/objectify_test directory"
   echo ""
   exit 1
fi

if ! rm -fr /tmp/test; then
   echo ""
   echo "could not remove /tmp/objectify_test directory"
   echo ""
   exit 1
fi

mkdir /tmp/test
cd /tmp/test

echo "----------------------"
echo " creating test files"
echo "----------------------"

#dd if=/dev/random of=x7 bs=7 count=1

echo "WARNING: NOT using random data!!!!!"
echo -n "1234567" > x7

cat          x7          x7 >        x14
cat         x14         x14 >        x28
cat         x28         x28 >        x56
cat         x56         x56 >       x112
cat        x112        x112 >       x224
cat        x224        x224 >       x448
cat        x448        x448 >       x896
cat        x896        x896 >      x1792
cat       x1792       x1792 >      x3584
cat       x3584       x3584 >      x7168
cat       x7168       x7168 >     x14336
cat      x14336      x14336 >     x28672
cat      x28672      x28672 >     x57344
cat      x57344      x57344 >    x114688
cat     x114688     x114688 >    x229376
cat     x229376     x229376 >    x458752
cat     x458752     x458752 >    x917504
cat     x917504     x917504 >   x1835008
cat    x1835008    x1835008 >   x3670016
cat    x3670016    x3670016 >   x7340032
cat    x7340032    x7340032 >  x14680064
cat   x14680064   x14680064 >  x29360128
cat   x29360128   x29360128 >  x58720256
cat   x58720256   x58720256 > x117440512


echo "---------------"
echo " prep disk..."
echo "---------------"
if ! $EXEC/src/apps/util/archive-prep; then
   echo ""
   echo "archive-prep failed"
   echo ""
   exit 1
fi

echo "---------------"
echo " file-imports..."
echo "---------------"
if ! $EXEC/src/apps/file/file-import x*; then
   echo ""
   echo "file-import failed"
   echo ""
   exit 1
fi


echo "-----------------"
echo " file-exports..."
echo "-----------------"

mkdir test
cd test

if ! $EXEC/src/apps/file/file-export "*"; then
   echo ""
   echo "file-export failed"
   echo ""
   exit 1
fi

for file in ../x*; do diff -s $file .; done
sleep 2

echo "---------------------"
echo " verify and remove..."
echo "---------------------"
if ! $EXEC/src/apps/file/file-verify --remove-no-shred *; then
   echo ""
   echo "file-verify --remove-no-shred succeeded"
   echo ""
   exit 1
fi


echo "---------------------"
echo " compress..."
echo "---------------------"
if ! $EXEC/src/apps/util/archive-compress ../compressed; then
   echo ""
   echo "archive-compress failed"
   echo ""
   exit 1
fi


echo "--------------------------"
echo " prep disk for restore..."
echo "--------------------------"
if ! $EXEC/src/apps/util/archive-prep --no-private; then
   echo ""
   echo "archive-prep --no-private failed"
   echo ""
   exit 1
fi


echo "---------------------"
echo " expand..."
echo "---------------------"
if ! $EXEC/src/apps/util/archive-restore ../compressed; then
   echo ""
   echo "archive-restore failed"
   echo ""
   exit 1
fi



if ! $EXEC/src/apps/file/file-export "*"; then
   echo ""
   echo "file-export failed"
   echo ""
   exit 1
fi

for file in ../*.[ch]; do diff -s $file .; done


echo "---------------------"
echo " verify and remove..."
echo "---------------------"
if ! $EXEC/src/apps/file/file-verify --remove-no-shred *; then
   echo ""
   echo "file-verify --remove-no-shred failed"
   echo ""
   exit 1
fi

echo ""
echo "All tests passed!"
echo ""

exit 0
